@@ -2,10 +2,12 @@ import duckdb
 import os
 from .filetype import FileType
 from .queryresult import QueryResult
+from typing import List
 
 READ_FUNCS = {
     FileType.CSV: 'read_csv_auto',
-    FileType.PARQUET: 'read_parquet'
+    FileType.PARQUET: 'read_parquet',
+    FileType.JSON: 'read_json_auto'
 }
 
 class FileDb:
@@ -20,8 +22,14 @@ class FileDb:
 
         # filename should be path to file
         def create_table_from_file(filename: str):
-            base_filename = os.path.basename(filename)
-            filetype = FileType.CSV if base_filename.endswith('.csv') else FileType.PARQUET
+            base_filename = os.path.basename(filename).lower()
+            filetype = FileType.CSV
+            
+            if base_filename.endswith('.parquet'):
+                filetype = FileType.PARQUET
+            elif base_filename.endswith('.json'):
+                filetype = FileType.JSON
+            
             table_name = os.path.splitext(base_filename)[0]
             read_func = READ_FUNCS[filetype]
 
@@ -29,7 +37,7 @@ class FileDb:
 
         if os.path.isdir(filepath):
             # only take csv and parquet files
-            files = [file for file in os.listdir(filepath) if file.lower().endswith('.csv') or file.lower().endswith('.parquet')]
+            files = [file for file in os.listdir(filepath) if file.lower().endswith('.csv') or file.lower().endswith('.parquet') or file.lower().endswith('.json')]
 
             for file in files:
                 create_table_from_file(os.path.join(filepath, file))
@@ -38,7 +46,8 @@ class FileDb:
 
     def exec_query(self, query: str) -> QueryResult:
         """
-        Executes a query in the database created from the file
+        Executes a query in the database created from the file. If more than one semicolon separated queries are given,
+        the result will only be given for the last one. Use the exec_many_queries() to get the result from multiple queries.
 
         :param query: query to execute
         :type query: str
@@ -47,11 +56,17 @@ class FileDb:
         """
         res = self.db.execute(query)
         return QueryResult(res.fetchnumpy())
+    
+    def exec_many_queries(self, queries: List[str]) -> List[QueryResult]:
+        results = [self.exec_query(query) for query in queries]
+        return results
 
     def export_query(self, query: str, output_filepath: str, filetype: int = FileType.CSV):
         """
         Writes query result to a file
 
+        TODO: allow multiple queries to be expored to multiple files
+
         :param query: query to execute
         :type query: str
         :param output_filepath: path to output file
